@@ -187,6 +187,8 @@ class ActivityList(list):
             )
             for a in valid_sorted:
                 value = key(a)
+                if value is None:
+                    continue
                 if total is None:
                     total = value - value
                 data[0].append(a.start_time)
@@ -217,6 +219,8 @@ class ActivityList(list):
                 continue
             for a in valid_sorted:
                 value = key(a)
+                if value is None:
+                    continue
                 if total is None:
                     total = value - value
                 data[0].append(start + times.since_start(a.start_time, time_period))
@@ -228,10 +232,9 @@ class ActivityList(list):
                 data[1].append(total)
             if back != 0:
                 data[0].append(times.end_of(times.EPOCH, time_period))
-                data[1].append(total)
             else:
                 data[0].append(times.EPOCH + times.since_start(now, time_period))
-                data[1].append(total)
+            data[1].append(total)
             result.append(data)
             periods.append(times.back_name(now, time_period, back))
 
@@ -269,6 +272,25 @@ class ActivityList(list):
                 result.append(track.lat_lon_list)
         return result
 
+    def get_matching(self, activity_, progress=lambda x: x):
+        matching = {activity_.activity_id}
+        if not activity_.track.has_position_data:
+            return matching
+        for other_activity in progress(self):
+            if other_activity.activity_id == activity_.activity_id or not (
+                other_activity.sport == activity_.sport
+                and other_activity.distance / 1.2
+                < activity_.distance
+                < other_activity.distance * 1.2
+            ):
+                continue
+            if activity_.track.match(
+                self.get_activity(other_activity.activity_id).track
+            ):
+                matching.add(other_activity.activity_id)
+
+        return matching
+
     def __repr__(self):
         return (
             f"<{self.__class__.__qualname__}"
