@@ -140,7 +140,7 @@ class MainWindow(QtWidgets.QMainWindow, Ui_main_window):
                 in self.social_activities.by_id(activity_id).server.split("\n")
             )
             self.social_activity = activity.Activity(
-                **serialise.load_bytes(
+                **serialise.loads(
                     server.get_data(f"get_activity/{activity_id}"), gz=True
                 )
             )
@@ -290,6 +290,23 @@ class MainWindow(QtWidgets.QMainWindow, Ui_main_window):
         self.activity_view.create()
         self.activity_view.showMaximized()
 
+    def match_activity(self):
+        self.activity_list_table.setUpdatesEnabled(False)
+        if self.action_match.text() == "Clear Match":
+            self.action_match.setText("Find Matching")
+            self.activity_list_table.filter({a.activity_id for a in self.activities})
+        else:
+            self.activity_list_table.filter(
+                self.activities.get_matching(
+                    self.activity,
+                    progress=lambda x: activate.app.dialogs.progress(
+                        self, x, "Finding matching activities"
+                    ),
+                )
+            )
+            self.action_match.setText("Clear Match")
+        self.activity_list_table.setUpdatesEnabled(True)
+
     def activity_view_closed(self):
         self.activity_summary.show_map()
         self.map_widget.remove_marker()
@@ -333,20 +350,20 @@ class MainWindow(QtWidgets.QMainWindow, Ui_main_window):
             self,
         )
         dialog.setWindowModality(Qt.WindowModal)
+        dialog.forceShow()
         for i, server in enumerate(self.settings.servers):
             dialog.setLabelText(f"Getting activity list from {server.name}")
+            dialog.setValue(SYNC_PROGRESS_STEPS * i)
             try:
                 server_activities = activity_list.from_serial(
-                    serialise.load_bytes(server.get_data("get_activities")), None
+                    serialise.loads(server.get_data("get_activities")), None
                 )
             except connect.requests.RequestException:
                 continue
             own_ids = set(a.activity_id for a in self.activities)
+            dialog.setValue(round(SYNC_PROGRESS_STEPS * (i + 1 / 3)))
             dialog.setLabelText(f"Syncing activities with {server.name}")
             for j, activity_ in enumerate(server_activities):
-                dialog.setValue(
-                    round(SYNC_PROGRESS_STEPS * (i + j / len(server_activities) / 2))
-                )
                 activity_.server = server.name
                 if activity_.username == server.username:
                     aid = activity_.activity_id
@@ -360,17 +377,24 @@ class MainWindow(QtWidgets.QMainWindow, Ui_main_window):
                     previous.username += f"\n{activity_.username}"
                 except KeyError:
                     self.social_activities.append(activity_)
+                dialog.setValue(
+                    round(
+                        SYNC_PROGRESS_STEPS
+                        * (i + (1 + (j + 1) / len(server_activities)) / 3)
+                    )
+                )
+            dialog.setValue(round(SYNC_PROGRESS_STEPS * (i + 2 / 3)))
             if not own_ids:
                 continue
             dialog.setLabelText(f"Uploading activities to {server.name}")
             for j, missing_id in enumerate(own_ids):
-                dialog.setValue(
-                    round(SYNC_PROGRESS_STEPS * (i + (1 + j / len(own_ids)) / 2))
-                )
                 try:
                     server.upload_activity(self.activities.get_activity(missing_id))
                 except connect.requests.RequestException:
                     break
+                dialog.setValue(
+                    round(SYNC_PROGRESS_STEPS * (i + (2 + (1 + j) / len(own_ids)) / 3))
+                )
         dialog.setValue(SYNC_PROGRESS_STEPS * len(self.settings.servers))
 
     def social_tab_update(self):
