@@ -4,6 +4,8 @@ from dataclasses import dataclass
 from datetime import datetime, timedelta
 from functools import lru_cache
 
+from dtw import dtw
+
 from activate import geometry, times
 from activate.units import DimensionValue
 
@@ -85,8 +87,12 @@ def get_nearby_indices(length, position, number=1) -> range:
     return range(max(position - number, 0), min(position + number + 1, length))
 
 
-def distance(point1, point2):
-    return math.sqrt(sum((c1 - c2) ** 2 for c1, c2 in zip(point1, point2)))
+try:
+    import dist
+except ImportError:
+
+    def dist(point1, point2):
+        return math.sqrt(sum((c1 - c2) ** 2 for c1, c2 in zip(point1, point2)))
 
 
 def enumerate_from(list_, point):
@@ -182,6 +188,14 @@ class Track:
             return self.has_altitude_data
         return field in self.fields
 
+    @property
+    @lru_cache(128)
+    def xyz(self):
+        return [
+            geometry.to_cartesian(*point)
+            for point in zip(self["lat"], self["lon"], self["ele"])
+        ]
+
     def calculate_dist_to_last(self):
         """Calculate distances between adjacent points"""
         self.fields["dist_to_last"] = [None]
@@ -192,12 +206,9 @@ class Track:
                     None if None in relevant else relevant[1] - relevant[0]
                 )
         else:
-            xyz = [
-                geometry.to_cartesian(*point)
-                for point in zip(self["lat"], self["lon"], self["ele"])
-            ]
             self.fields["dist_to_last"] += [
-                distance(xyz[point], xyz[point - 1]) for point in range(1, len(self))
+                dist(self.xyz[point], self.xyz[point - 1])
+                for point in range(1, len(self))
             ]
 
     def calculate_climb_desc(self):
@@ -559,6 +570,9 @@ class Track:
             point_indices,
         )
 
+    def match(self, other):
+        return dtw(self.xyz, other.xyz, distance_only=True).normalizedDistance < 40
+
     @property
     def save_data(self):
         return {
